order_hash

Function order_hash 

pub fn order_hash(order: &PolymarketOrder, neg_risk: bool) -> Result<B256>
Computes the EIP-712 signing hash used by Polymarket as the order ID.

The neg_risk flag selects which exchange contract to use as the EIP-712 verifyingContract.